-- https://github.com/moody/TransmogExpander

local AddonName = ...

-- Upvalues
local WardrobeFrame = _G.WardrobeFrame
local TransmogFrame = _G.WardrobeTransmogFrame
local ModelFrame = _G.WardrobeTransmogFrame.ModelScene
local CollectionFrame = _G.WardrobeCollectionFrame
local WardrobeOutfitDropDown = _G.WardrobeOutfitDropDown

-- Variables
local initialized = false

-- ============================================================================
-- Hook WardrobeFrame's OnShow
-- ============================================================================

local function onShow()
  if initialized then return end
  -- Resize main frame
  WardrobeFrame:SetWidth(1280)
  -- Resize transmog frame
  TransmogFrame:SetPoint("TOPLEFT", WardrobeFrame, 4, -60)
  TransmogFrame:SetPoint("BOTTOMRIGHT", CollectionFrame, "BOTTOMLEFT", 0, TransmogFrame.ApplyButton:GetHeight() + 3)
  TransmogFrame.Inset.BG:SetAllPoints() -- Fill background
  TransmogFrame.MoneyMiddle:SetPoint("RIGHT", TransmogFrame.SpecButton, "LEFT", -7, 0)
  -- Center model
  ModelFrame:SetPoint("TOPLEFT", TransmogFrame, 75, -20)
  ModelFrame:SetPoint("BOTTOMRIGHT", TransmogFrame, -75, 20)
  ModelFrame.ClearAllPendingButton:SetPoint("TOPRIGHT", TransmogFrame, -20, -20)

  do -- Position outfit drop-down menu
    local positioner = TransmogFrame:CreateTexture(AddonName.."DropDownTexture", "BACKGROUND")
    positioner:SetPoint("TOPLEFT", WardrobeOutfitDropDown)
    positioner:SetPoint("BOTTOMLEFT", WardrobeOutfitDropDown)
    positioner:SetPoint("RIGHT", WardrobeOutfitDropDown.SaveButton)
    local width, height = positioner:GetSize()
    positioner:ClearAllPoints()
    positioner:SetSize(width, height)
    positioner:SetPoint("BOTTOM", TransmogFrame, "TOP", 0, 6)
    WardrobeOutfitDropDown:ClearAllPoints()
    WardrobeOutfitDropDown:SetPoint("BOTTOMLEFT", positioner)
  end

  do -- Position left-side transmog buttons
    local positioner = TransmogFrame:CreateTexture(AddonName.."LeftButtonsTexture", "BACKGROUND")
    positioner:SetPoint("TOPLEFT", ModelFrame.HeadButton)
    positioner:SetPoint("BOTTOMRIGHT", ModelFrame.WristButton)
    local width, height = positioner:GetSize()
    positioner:ClearAllPoints()
    positioner:SetSize(width, height)
    positioner:SetPoint("LEFT", TransmogFrame, 20, 0)
    ModelFrame.HeadButton:ClearAllPoints()
    ModelFrame.HeadButton:SetPoint("TOPLEFT", positioner)
  end

  do -- Position right-side transmog buttons
    local positioner = TransmogFrame:CreateTexture(AddonName.."RightButtonsTexture", "BACKGROUND")
    positioner:SetPoint("TOPLEFT", ModelFrame.HandsButton)
    positioner:SetPoint("BOTTOMRIGHT", ModelFrame.FeetButton)
    local width, height = positioner:GetSize()
    positioner:ClearAllPoints()
    positioner:SetSize(width, height)
    positioner:SetPoint("RIGHT", TransmogFrame, -20, 0)
    ModelFrame.HandsButton:ClearAllPoints()
    ModelFrame.HandsButton:SetPoint("TOPLEFT", positioner)
  end

  do -- Position bottom-side transmog buttons
    local positioner = TransmogFrame:CreateTexture(AddonName.."BottomButtonsTexture", "BACKGROUND")
    positioner:SetPoint("TOPLEFT", ModelFrame.MainHandButton)
    positioner:SetPoint("BOTTOMRIGHT", ModelFrame.SecondaryHandButton)
    local width, height = positioner:GetSize()
    positioner:ClearAllPoints()
    positioner:SetSize(width + 225, height)
    positioner:SetPoint("BOTTOM", TransmogFrame, 0, 25)
    ModelFrame.MainHandButton:ClearAllPoints()
    ModelFrame.MainHandButton:SetPoint("TOPLEFT", positioner)
    ModelFrame.MainHandEnchantButton:SetPoint("CENTER", ModelFrame.MainHandButton.Border, "BOTTOM", 0, 5)
    ModelFrame.SecondaryHandButton:ClearAllPoints()
    ModelFrame.SecondaryHandButton:SetPoint("TOPRIGHT", positioner)
    ModelFrame.SecondaryHandEnchantButton:SetPoint("CENTER", ModelFrame.SecondaryHandButton.Border, "BOTTOM", 0, 5)
  end

  initialized = true
end

WardrobeFrame:HookScript("OnShow", onShow)
